@@ -9,7 +9,7 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 
-DOCUMENTATION = '''
+DOCUMENTATION = r'''
 ---
 module: vmware_guest_info
 short_description: Gather info about a single VM
@@ -43,7 +43,7 @@ options:
    use_instance_uuid:
      description:
      - Whether to use the VMware instance UUID rather than the BIOS UUID.
-     default: no
+     default: false
      type: bool
    moid:
      description:
@@ -74,11 +74,20 @@ options:
    tags:
      description:
      - Whether to show tags or not.
-     - If set C(True), shows tag information.
+     - If set C(True), shows tags information. Returns a list of tag names.
      - If set C(False), hides tags information.
-     - vSphere Automation SDK and vCloud Suite SDK is required.
-     default: 'no'
+     - vSphere Automation SDK is required.
+     default: false
      type: bool
+   tag_details:
+     description:
+     - If set C(True), detail information about 'tags' returned.
+     - Without this flag, the 'tags' returns a list of tag names.
+     - With this flag, the 'tags' returns a list of dict about tag information with additional details like category name, category id, and tag id.
+     - This parameter is added to maintain backward compatability.
+     default: false
+     type: bool
+     version_added: '1.4.0'
    schema:
      description:
      - Specify the output schema desired.
@@ -109,14 +118,13 @@ extends_documentation_fragment:
 
 '''
 
-EXAMPLES = '''
+EXAMPLES = r'''
 - name: Gather info from standalone ESXi server having datacenter as 'ha-datacenter'
   community.vmware.vmware_guest_info:
     hostname: "{{ vcenter_hostname }}"
     username: "{{ vcenter_username }}"
     password: "{{ vcenter_password }}"
     datacenter: ha-datacenter
-    validate_certs: no
     uuid: 421e4592-c069-924d-ce20-7e7533fab926
   delegate_to: localhost
   register: info
@@ -126,7 +134,6 @@ EXAMPLES = '''
     hostname: "{{ vcenter_hostname }}"
     username: "{{ vcenter_username }}"
     password: "{{ vcenter_password }}"
-    validate_certs: no
     datacenter: "{{ datacenter_name }}"
     name: "{{ vm_name }}"
     schema: "vsphere"
@@ -139,7 +146,6 @@ EXAMPLES = '''
     hostname: "{{ vcenter_hostname }}"
     username: "{{ vcenter_username }}"
     password: "{{ vcenter_password }}"
-    validate_certs: no
     datacenter: "{{ datacenter_name }}"
     moid: vm-42
     schema: "vsphere"
@@ -152,7 +158,6 @@ EXAMPLES = '''
     hostname: "{{ vcenter_hostname }}"
     username: "{{ vcenter_username }}"
     password: "{{ vcenter_password }}"
-    validate_certs: no
     datacenter: "{{ datacenter_name }}"
     name: "{{ vm_name }}"
     schema: "vsphere"
@@ -160,9 +165,20 @@ EXAMPLES = '''
       - _moId
   delegate_to: localhost
   register: moid_info
+
+- name: Gather detailed information about tags and category associated with the given VM
+  community.vmware.vmware_guest_info:
+    hostname: "{{ vcenter_hostname }}"
+    username: "{{ vcenter_username }}"
+    password: "{{ vcenter_password }}"
+    datacenter: "{{ datacenter_name }}"
+    name: "{{ vm_name }}"
+    tags: True
+    tag_details: True
+  register: detailed_tag_info
 '''
 
-RETURN = """
+RETURN = r'''
 instance:
     description: metadata about the virtual machine
     returned: always
@@ -223,7 +239,7 @@ instance:
         "moid": "vm-42",
         "vimref": "vim.VirtualMachine:vm-42"
     }
-"""
+'''
 
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils._text import to_text
@@ -255,7 +271,8 @@ def main():
         datacenter=dict(type='str', required=True),
         tags=dict(type='bool', default=False),
         schema=dict(type='str', choices=['summary', 'vsphere'], default='summary'),
-        properties=dict(type='list', elements='str')
+        properties=dict(type='list', elements='str'),
+        tag_details=dict(type='bool', default=False),
     )
     module = AnsibleModule(argument_spec=argument_spec,
                            required_one_of=[['name', 'uuid', 'moid']],
@@ -293,12 +310,15 @@ def main():
                                          " - https://code.vmware.com/web/sdk/60/vcloudsuite-python")
 
                 vm_rest_client = VmwareTag(module)
-                dynamic_obj = DynamicID(type='VirtualMachine', id=vm._moId)
-                instance.update(
-                    tags=vm_rest_client.get_vm_tags(vm_rest_client.tag_service,
-                                                    vm_rest_client.tag_association_svc,
-                                                    vm_mid=dynamic_obj)
-                )
+                tags = []
+                if module.params.get('tag_details'):
+                    tags = vm_rest_client.get_tags_for_vm(vm_mid=vm._moId)
+                else:
+                    dynamic_obj = DynamicID(type='VirtualMachine', id=vm._moId)
+                    tags = vm_rest_client.get_vm_tags(vm_rest_client.tag_service,
+                                                      vm_rest_client.tag_association_svc,
+                                                      vm_mid=dynamic_obj)
+                instance.update(tags=tags)
             module.exit_json(instance=instance)
         except Exception as exc:
             module.fail_json(msg="Information gathering failed with exception %s" % to_text(exc))
